package ${groupId};

import org.springframework.mock.web.MockHttpServletRequest;
import org.springframework.mock.web.MockHttpServletResponse;
import org.springframework.test.AbstractTransactionalSpringContextTests;
import org.springframework.web.servlet.ModelAndView;

import jp.co.pwv.utils.DbUnitHelperDao;
import ${groupId}.service.MemberManager;
import ${groupId}.web.EditMemberController;
import ${groupId}.web.MemberOpsController;
import ${groupId}.domain.Member;


public class TestCase
	extends AbstractTransactionalSpringContextTests {	
	private MemberManager	memberManager;
	private DbUnitHelperDao dbUnitHelperDao;

	public String[] getConfigLocations() {
		return new String[] {
				"WEB-INF/applicationContext.xml",
				"WEB-INF/custom-editor.xml",
				"WEB-INF/db-def.xml",
				"WEB-INF/servlet-def.xml",
				"WEB-INF/servlet-stub.xml",
				"testdata-def.xml"
		};
	}

	public void onSetUpInTransaction() throws Exception {
		super.onSetUpInTransaction();
		memberManager = (MemberManager)getApplicationContext().getBean("memberManager");
		dbUnitHelperDao = (DbUnitHelperDao)getApplicationContext().getBean("dbUnitHelperDao");
		dbUnitHelperDao.addHelper(memberManager.getHelper());
	}

	public void onTearDownInTransaction() throws Exception {
		super.onTearDownInTransaction();
	}	

	//	memberManager test
	public void testFindById() {		
		dbUnitHelperDao.restore("src/test/resources/dump.xml");

		Member member = memberManager.findById(new Integer(1));
		assertEquals("Hiroshi TAKEMOTO", member.getName());
		assertEquals("Nakano-ku", member.getAddress());	
		// or you can check using IMember.print method.
		Member expectedMember = (Member)getApplicationContext().getBean("expectedMember");
		System.out.println(memberManager.print(member));
		assertEquals(memberManager.print(expectedMember), memberManager.print(member));
	}
	//	editMemberController test
	public void testEditMemberController() {
		dbUnitHelperDao.restore("src/test/resources/dump.xml");

		MockHttpServletRequest req = new MockHttpServletRequest("POST","editMember.htm");
		req.addParameter("id","1");
		EditMemberController	editMemberController = (EditMemberController)getApplicationContext().getBean("editMemberController");
		ModelAndView mv = null;
		try {
			mv = editMemberController.handleRequest(req,new MockHttpServletResponse());
		} catch (Exception err) {
			err.printStackTrace();
		}
		Member expectedMember = (Member)getApplicationContext().getBean("expectedMember");

		assertEquals("redirect:memberops/list.htm", mv.getViewName());
		Member member = (Member)mv.getModel().get("member");
		assertEquals(memberManager.print(expectedMember), memberManager.print(member));

	}
	//	memberOpsController list method test
	public void testmemberOpsController_List() {
		dbUnitHelperDao.restore("src/test/resources/dump.xml");

		MockHttpServletRequest req = new MockHttpServletRequest("POST","memberops/list.htm");
		MemberOpsController	memberOpsController = (MemberOpsController)getApplicationContext().getBean("memberOpsController");
		ModelAndView mv = null;
		try {
			mv = memberOpsController.handleRequest(req,new MockHttpServletResponse());
		} catch (Exception err) {
			err.printStackTrace();
		}
		Member expectedMember = (Member)getApplicationContext().getBean("expectedMember");

		assertNull(mv.getViewName());
		Member[] members = (Member[])mv.getModel().get("memberList");
		assertEquals(memberManager.print(expectedMember), memberManager.print(members[0]));		
	}
}
